* PROGRAM TO GENERATE FITTED VALUES OF CONSUMER SPENDING 
* FOR INSTRUMENT LISTS EXCLUDING AND INCLUDING SENTIMENT

* corrected for problems David found looking through the code

* source(noecho) LOADDAT.R

declare string nosent
declare string withsent
declare string sentstr
declare string oidstr
declare string idorder
declare string senttype
declare string notmood
declare string constype
  
do model = 1,1

* loop over several sets instruments
do whichins = 1,3

do sent = 11,11

if sent == 9 {
display(store=senttype) 'Composite Sentiment Index'
}

if sent == 10 {
display(store=senttype) 'Expectations Sentiment Index'
}

if sent == 11 {
display(store=senttype) 'Unemployment Sentiment Index'
}

* loop over different consumption measures

do i = 30,30

if i == 27 {
display(store=constype) 'Total Consumption'
}
if i == 28 {
display(store=constype) 'Services Consumption'
}
if i == 29 {
display(store=constype) 'Motor Vehicles Consumption'
}
if i == 30 {
display(store=constype) 'Goods ex MV Consumption'
}

eval fulltest = 0
* This determines whether the SOLVECM program also tests
* whether past sentiment helps predict current sentiment
* and the current value of the other RHS variable

smpl 61:1 93:2

  eval a0 = .001
  eval a1 = .5
  eval a2 = .1
  eval a3 = -.1
  eval a4 = .05
  eval a5 = .05
  eval theta = .4
  eval gamma = .01

* fl is the nonlinear formula corresponding to the model
* idorder is the number of identifying restrictions
* (i.e. the number of variables which are instrumented for)

if model == 0 {
  display '**************** Davids Original Standard model ************'
* to duplicate original results must use instrument list 1
* and sentiment variable = miindexq (sent = 9)
  nonlin a0 a1 theta gamma
  frml fl = a0 + a1*(v1=zypd82(t)+theta*if$(t==54:1,0,v1)) $
               -    (v2=i(t)     +theta*if$(t==54:1,gamma,v2))
  display(store=exclsent) '2'
  display(store=idorder) '2'
  display(store=notmood) 'miunempq'
}


if model == 1 {
  display '********* Campbell suggestion, four lags of sentiment ********'
  nonlin a0 a1 a2 a3 a4 a5 theta gamma
  frml fl = a0 + a1*(v1=zypd82(t)    +theta*if$(t==54:1,0,v1)) $
               + a2*(v2=miunempq(t-1)+theta*if$(t==54:1,0,v2)) $
               + a3*(v3=miunempq(t-2)+theta*if$(t==54:1,0,v3)) $
               + a4*(v4=miunempq(t-3)+theta*if$(t==54:1,0,v4)) $
               + a5*(v5=miunempq(t-4)+theta*if$(t==54:1,0,v5)) $
               -    (v6=i(t)         +theta*if$(t==54:1,gamma,v6))
  display(store=exclsent) '3 4 5 6'
  display(store=idorder) '6'
* this idorder assumption comes from adding all the right hand side
* variables, including theta but not gamma, but excluding the constant
* because the constant is also excluded from the oidlen variable
}


if model == 2 {
  display '********** Campbell suggestion, one lag sentiment ********'
* to duplicate original results must use instrument list 1
* and sentiment variable = miunempq (sent = 9)
  nonlin a0 a1 a2 theta gamma
  frml fl = a0 + a1*(v1=zypd82(t)    +theta*if$(t==54:1,0,v1)) $
               + a2*(v2=miunempq(t-1)+theta*if$(t==54:1,0,v2)) $
               -    (v3=i(t)         +theta*if$(t==54:1,gamma,v3))
  display(store=exclsent) '3'
}

  set nothing / = 0.0


if whichins == 1 {
  display '!!!!!!!!!!!!!!!!!!!!!!!!!!! First instrument set. !!!!!!!!!'
  display(store=nosent)   'c i{1 to 4} zypd82{1 to 4} ecm{1}'
  display(store=sentstr)  'sent{1 to 4}'
  display(store=oidlen)   '9'
  display(store=sentlen)  '4'
}


if whichins == 2 {
  display '!!!!!!!!!!!!!!!!!!!!!!!!!!! Second instrument set. !!!!!!!!!'
  display(store=nosent)   'c zsp{1} zu{1} i{1} zy{1} ecm{1}'
  display(store=sentstr)  'sent{1 to 4}'
  display(store=oidlen)   '5'
  display(store=sentlen)  '4'
}


if whichins == 3 {
  display '!!!!!!!!!!!!!!!!!!!!!!!!!!! Fuhrer instrument set. !!!!!!!!'
  display(store=nosent)   'c zu{1 2} i{1 2} zy{1 2} zf{1 2} s{1 2}'
  display(store=sentstr)  'sent{1 to 4}'
  display(store=oidlen)   '10'
  display(store=sentlen)  '4'
}


if whichins == 4 {
  display '!!!!!!!!!!!!!!!! First instrument set, one lag sent !!!!!!!!!'
  display(store=nosent)   'c i{1 to 4} zypd82{1 to 4} ecm{1}'
  display(store=sentstr)  'sent{1}'
  display(store=oidlen)   '9'
  display(store=sentlen)  '1'
}

if whichins == 5 {
  display '!!!!!!!!!!!!!!!!! Second instrument set, one lag sent !!!!!!!!!'
  display(store=nosent)   'c zsp{1} zu{1} i{1} zy{1} ecm{1}'
  display(store=sentstr)  'sent{1}'
  display(store=oidlen)   '5'
  display(store=sentlen)  '1'
}


if whichins == 6 {
  display '!!!!!!!!!!!!!!!!  Fuhrer instrument set, one lag sent !!!!!!!!'
  display(store=nosent)   'c zu{1 2} i{1 2} zy{1 2} zf{1 2} s{1 2}'
  display(store=sentstr)  'sent{1}'
  display(store=oidlen)   '10'
  display(store=sentlen)  '1'
}

source(noecho) SOLVECM.CAMPBELL.R

end do i
end do sent
end do whichins
end do model
