* PROGRAM TO FORECAST 6 MEASURES OF CONSUMPTION  
* REPLICATING CAMPBELL-MANKIW INSTRUMENTAL VARIABLES
*     quarterly data
bma expressions 1000 compile 9000
cal 50 1 4 
alloc  74 (95,4)

smpl 50:1 90:4

* michigan index begins nov 52
* conf. bd index begins feb 69
* michigan expectations begins jan 53
* conf. bd expectations begins  jan 78


eqv 1 to 16
    c82 cd82 cn82 cs82 cmv82 cfuel82 ypd82 tbill $
    miindexq miexpcnq $
    zc82 zcs82 zcmv82 zcontr82 $
    sandp unemp

open data RATSDATA
data(unit=data, format=rats) / $
unemp c82 cd82 cmv82 cn82 cs82 ypd82 fedfn cpapr tbill6 miindexq $
miexpcnq miunempq sandp
close data RATSDATA

* create log diffs of consumption series 

   set contr82  / = cd82(t) + cn82(t) - cmv82(t)

   set zc82     / = log(c82(t))     - log(c82(t-1))
   set zcs82    / = log(cs82(t))    - log(cs82(t-1))
   set zcmv82   / = log(cmv82(t))   - log(cmv82(t-1))
   set zcontr82 / = log(contr82(t)) - log(contr82(t-1))
   set zypd82   / = log(ypd82(t))   - log(ypd82(t-1))
   set zsandp   / = log(sandp(t))   - log(sandp(t-1))
   set zunemp   / = unemp(t)        - unemp(t-1)

   set ecm      / = log(c82(t))     - log(ypd82(t))   
 
****************************************
* instruments lagged once
****************************************  

do sent = 9,10
 do i = 11,14

* reduced form 

  instruments constant sent{1 to 4}
  linreg(inst,robusterrors) i 54:1 90:4 
# constant sent{1 to 4}
  exclude 
# sent{1 to 4}


  instruments constant i{1 to 4} zypd82{1 to 4} ecm{1}
  linreg(inst,robusterrors) i 54:1 90:4 
# constant i{1 to 4} zypd82{1 to 4} ecm{1}

  fetch crsq1 = rbarsq

  instruments constant i{1 to 4} zypd82{1 to 4} ecm{1} sent{1 to 4}
  linreg(inst,robusterrors) i 54:1 90:4 
# constant i{1 to 4} zypd82{1 to 4} ecm{1} sent{1 to 4}

  fetch crsq2 = rbarsq
  eval  rsqdiff = crsq2 - crsq1
  write rsqdiff

  exclude 
# sent{1 to 4}

 end do i
end do sent

* repeat for shorter sample period

do sent = 9,10
 do i = 11,14

* reduced form 

  instruments constant sent{1 to 4}
  linreg(inst,robusterrors) i 78:1 90:4 
# constant sent{1 to 4}
  exclude 
# sent{1 to 4}


  instruments constant i{1 to 4} zypd82{1 to 4} ecm{1}
  linreg(inst,robusterrors) i 78:1 90:4 
# constant i{1 to 4} zypd82{1 to 4} ecm{1}


  fetch crsq1 = rbarsq

  instruments constant i{1 to 4} zypd82{1 to 4} ecm{1} sent{1 to 4}
  linreg(inst,robusterrors) i 78:1 90:4 
# constant i{1 to 4} zypd82{1 to 4} ecm{1} sent{1 to 4}


  fetch crsq2 = rbarsq
  eval  rsqdiff = crsq2 - crsq1
  write rsqdiff

  exclude 
# sent{1 to 4}

 end do i
end do sent



